@@ -5,21 +5,25 @@ from ..transport import DoHomeBroadcastTransport
 from .light import DoHomeLight
 from .light import parse_response
 
+NotAllException = Exception("Not all lights responds")
+
 class DoHomeLightsBroadcast(DoHomeLight):
     """DoHome broadcast light controller class"""
     _transport: DoHomeBroadcastTransport
+    _timeout: float
 
-    def __init__(self, sids: List[str], transport: DoHomeBroadcastTransport):
+    def __init__(self, sids: List[str], transport: DoHomeBroadcastTransport, timeout = 1.0):
         super().__init__(sids, transport)
         self._sids = sids
+        self._timeout = timeout
 
     async def _send_request(self, request: str):
         response_data = await self._transport.send_request(
-            request, 1, len(self._sids)
+            request, self._timeout, len(self._sids)
         )
         responses = list(map(parse_response, response_data))
         if len(responses) != len(self._sids):
-            raise Exception("Not all lights responds")
+            raise NotAllException
         for response in responses:
             if response["res"] != 0:
                 raise Exception('Command error')
